import { Observable, OperatorFunction } from 'rxjs';
/**
 * It's like {@linkcode https://rxjs-dev.firebaseapp.com/api/operators/exhaustMap exhaustMap}, except it debounces upstream emissions until the previous result completes.
 *
 * ```
 * source:                     -0-1-2-------3-|
 *                              i--B-|
 *                                   i--B-|
 *                                          i--B-|
 * debounceMap((i) => i--B-|): -0--B-2--B---3--B-|
 */
export declare function debounceMap<UpstreamType, DownstreamType>(map: (input: UpstreamType) => Observable<DownstreamType> | PromiseLike<DownstreamType>): OperatorFunction<UpstreamType, DownstreamType>;
