import { Predicate } from '@angular/core';
import { MonoTypeOperatorFunction } from 'rxjs';
/**
 * Works like `filter()`, but always lets through the first emission for each new subscriber. This makes it suitable for subscribers that expect the observable to behave like a `BehaviorSubject`, where the first emission is processed synchronously during the call to `subscribe()`.
 *
 * ```
 * source:                   |-false--true--false--true--false--true-|
 * filterBehavior(identity): |-false--true---------true---------true-|
 * filterBehavior(identity):        |-true---------true---------true-|
 * filterBehavior(identity):              |-false--true---------true-|
 * ```
 */
export declare function filterBehavior<T>(predicate: Predicate<T>): MonoTypeOperatorFunction<T>;
