import { Constructor } from '@s-libs/js-core';
import { Observable, Subscription } from 'rxjs';
/**
 * Mixes in {@link SubscriptionManager} as an additional superclass.
 *
 * ```ts
 * class MySubclass extends mixInSubscriptionManager(MyOtherSuperclass) {
 *   subscribeAndManage(observable: Observable<any>) {
 *     this.subscribeTo(observable);
 *   }
 * }
 * ```
 */
export declare function mixInSubscriptionManager<B extends Constructor>(Base: B): {
    new (...args: any[]): {
        "__#5@#subscriptions": Subscription;
        subscribeTo<T>(observable: Observable<T>, next?: (value: T) => void, error?: (error: any) => void, complete?: () => void): void;
        manage(subscription: Subscription): void;
        unsubscribe(): void;
    };
} & B;
declare const SubscriptionManager_base: {
    new (...args: any[]): {
        "__#5@#subscriptions": Subscription;
        subscribeTo<T>(observable: Observable<T>, next?: ((value: T) => void) | undefined, error?: ((error: any) => void) | undefined, complete?: (() => void) | undefined): void;
        manage(subscription: Subscription): void;
        unsubscribe(): void;
    };
} & ObjectConstructor;
/**
 * Tracks all subscriptions to easily unsubscribe from them all during cleanup. Also binds callbacks to `this` for convenient use as a superclass, e.g.:
 *
 * ```ts
 * class EventLogger extends SubscriptionManager {
 *   constructor(private prefix: string, event$: Observable<string>) {
 *     super();
 *
 *     // you can pass in an instance method here and it will be bound to `this`
 *     this.subscribeTo(event$, this.log);
 *   }
 *
 *   log(event: string) {
 *     // even though this is used as a callback, you can still use `this`
 *     console.log(this.prefix + event);
 *   }
 * }
 * ```
 */
export declare class SubscriptionManager extends SubscriptionManager_base {
}
export {};
